商店 | NoneBot
Description: 跨平台 Python 异步 QQ 机器人框架

# # 商店

协议
插件
机器人
​
Filter Plugin

服务器状态查看
通过戳一戳获取服务器状态
nonebot_plugin_status yanyongyu
Copied!
HarukaBot
将B站UP主的动态和直播信息推送至QQ
haruka_bot SK-415
Copied!
rauthman
基于规则的授权管理
nonebot_plugin_rauthman Lancercmd
Copied!
NoneBot离线文档
在本地浏览NoneBot文档
nonebot_plugin_docs nonebot
Copied!
Sentry日志监控
使用Sentry监控机器人日志并处理报错
nonebot_plugin_sentry yanyongyu
Copied!
前端测试机器人插件
在浏览器中测试你的 NoneBot 机器人
nonebot_plugin_test yanyongyu
Copied!
定时任务
APScheduler 定时任务插件
nonebot_plugin_apscheduler yanyongyu
Copied!
图片搜索
从基本上所有你想的出名字的搜图平台找图片
nonebot_plugin_picsearcher synodriver
Copied!
通用数据库连接
连接至各种数据库,为其他插件导出连接对象
nonebot_plugin_navicat synodriver
Copied!
translator
多语种翻译插件
nonebot_plugin_translator Lancercmd
Copied!